<template>
  <a-spin :spinning='load'>
    <a-card :bordered='false'>
      <!-- 查询区域 -->
      <div class='table-page-search-wrapper'>
        <a-form layout='inline' @keyup.enter.native='searchQuery'>
          <a-row :gutter='24'>
            <a-col :md='6' :sm='8'>
              <a-form-item label='参数组编号'>
                <a-input v-model='queryParam.code' placeholder='请输入参数组编号'></a-input>
              </a-form-item>
            </a-col>
            <a-col :md='6' :sm='8'>
              <a-form-item label='参数组名称'>
                <a-input v-model='queryParam.name' placeholder='请输入参数组名称'></a-input>
              </a-form-item>
            </a-col>
            <a-col :md='6' :sm='8'>
            <span class='table-page-search-submitButtons' style='float: left;overflow: hidden;'>
              <a-button icon='search' type='primary' @click='searchQuery'>查询</a-button>
              <a-button icon='reload' style='margin-left: 8px' type='primary' @click='searchReset'>重置</a-button>
              <a-button icon='plus' style='margin-left: 8px' type='primary' @click='handleAdd'>新增参数组</a-button>
            </span>
            </a-col>
          </a-row>
        </a-form>
      </div>
      <div>
        <a-table
          ref='table'
          :columns='columns'
          :customRow='clickThenSelect'
          :dataSource='dataSource'
          :loading='loading'
          :pagination='ipagination'
          :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange, type:'radio'}"
          bordered
          class='j-table-force-nowrap'
          rowKey='id'
          size='small'
          @change='handleTableChange'
        >
          <!--状态栏个性展示-->
          <span slot='action' slot-scope='text, record'>
          <a href='javascript:' @click='handleEdit(record)'>编辑</a>
          <a-divider type='vertical' />
           <a-popconfirm title='确定删除吗?' @confirm='() => handleDelete(record.id)'>
                  <a>删除</a>
           </a-popconfirm>
            <!--          <a-divider type='vertical' />-->
            <!--         <a href='javascript:' @click=''>数据</a>-->
        </span>
        </a-table>
      </div>
      <!-- table区域-end -->

      <!-- 表单区域 -->
      <parameter-group-model ref='modalForm' :server-id='serverId' @ok='modalFormOk' />
    </a-card>
  </a-spin>
</template>

<script>
import ParameterGroupModel from './ParameterGroupModel'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import JDictSelectTag from '@/components/dict/JDictSelectTag'
import JInput from '@/components/jeecg/JInput'
import JEllipsis from '@/components/jeecg/JEllipsis'
import { deleteAction, getAction } from '@/api/manage'

export default {
  name: 'ParameterGroup',
  mixins: [JeecgListMixin],
  components: {
    ParameterGroupModel,
    JDictSelectTag,
    JInput,
    JEllipsis
  },
  data() {
    return {
      columns: [
        {
          title: '',
          dataIndex: '',
          key: 'rowIndex',
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          }
        },
        {
          title: '参数组编号',
          align: 'center',
          dataIndex: 'code'
        },
        {
          title: '参数组名称',
          align: 'center',
          dataIndex: 'name'
        },
        {
          title: '采集等级',
          align: 'center',
          dataIndex: 'collectionCycle',
          customRender: function(t) {
            if (t == 1000) {
              return '一级'
            } else if (t == 5000) {
              return '二级'
            } else if (t == 10000) {
              return '三级'
            }
            return ''
          }
        },
        {
          title: '描述',
          align: 'center',
          dataIndex: 'remark',
          customRender: function(text) {
            return !text ? '' : (text.length > 10 ? text.substr(0, 10) : text)
          }
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: 'center',
          scopedSlots: { customRender: 'action' }
        }
      ],
      load: false,
      url: {
        list: '/parameter/group/list',
        put: '/serve/deploy/collect/put',
        deploy: '/serve/deploy/deploy/document',
        delete: '/parameter/group/delete'
      }
    }
  },
  props: ['serverId', 'tree'],
  watch: {
    serverId: {
      handler() {
        this.loadData()
      }
    }
  },
  methods: {
    // 查询终端列表
    loadData(arg) {
      //加载数据 若传入参数1则加载第一页的内容
      if (arg === 1) {
        this.ipagination.current = 1
      }
      this.onClearSelected()
      var params = this.getQueryParams()//查询条件
      params.equipmentId = this.serverId
      this.loading = true
      getAction(this.url.list, params).then((res) => {
        if (res.success) {
          this.dataSource = res.result.records
          this.ipagination.total = res.result.total
          if (res.result.records.length > 0) {
            this.selectedRowKeys[0] = this.dataSource[0].id
          }
        }
        if (res.code === 510) {
          this.$message.warning(res.message)
        }
        this.loading = false
      })

    },
    handleDelete(id) {
      if (!this.url.delete) {
        this.$message.error('请设置url.delete属性!')
        return
      }
      var that = this
      deleteAction(that.url.delete, { id: id }).then((res) => {
        if (res.success) {
          that.$message.success(res.message)
          that.loadData()
          this.$emit('tree')
        } else {
          that.$message.warning(res.message)
        }
      })
    },
    clickThenSelect(record) {
      return {
        on: {
          click: () => {
            this.onSelectChange(record.id.split(','), [record])
          }
        }
      }
    },
    onSelectChange(selectedRowKeys) {
      this.selectedRowKeys = selectedRowKeys
    },
    modalFormOk(val) {
      // 调用父组件方法
      this.$emit('tree')
      // 新增/修改 成功时，重载列表
      this.loadData()
      this.selectedRowKeys = [val.id]
    },
    searchQuery() {
      this.loadData()
      this.onClearSelected()
    },
    searchReset() {
      this.queryParam = {}
      this.loadData()
      this.onClearSelected()
    },
    handleEdit(record) {
      this.$refs.modalForm.edit(record)
      this.$refs.modalForm.title = '编辑'
      this.$refs.modalForm.disableSubmit = false
    }
  }
}
</script>
<style>
</style>
